use maud::{Markup, html};

use crate::icons;

use super::empty;

pub fn desktop_minimal(content: Markup, name: &str) -> Markup {
    let content = html! {
        div class="w-full h-screen flex" {
            div class="max-md:hidden w-56" {
                (sidebar())
            }
            div class="w-full h-full flex flex-col" {
                div class="overflow-y-auto" {
                    (content)
                }
                div class="md:hidden mt-auto" {
                    (dock())
                }
            }
        }
    };

    empty(content, name)
}

pub fn desktop(content: Markup, name: &str, back_button: bool) -> Markup {
    let content = html! {
        div class="flex justify-center" {
            div class="p-5 w-full max-w-2xl" {
                (header(name, back_button))
                (content)
            }
        }
    };

    desktop_minimal(content, name)
}

fn sidebar() -> Markup {
    html! {
        ul class="menu w-full h-full bg-base-200" {
            li {
                div class="pt-3 pb-6 mt-3" {
                    h2 { "Timo's Workouts" }
                }
                a href="/" {
                    div class="size-5" { (icons::house()) }
                    "Overview"
                }
                a href="/workouts" {
                    div class="size-5" { (icons::barbell()) }
                    "Workouts"
                }
                a href="/exercises" {
                    div class="size-5" { (icons::person_simple_run()) }
                    "Exercises"
                }
            }
        }
    }
}

fn dock() -> Markup {
    html! {
        div class="dock" {
            a href="/" {
                div class="size-[1.5em]" { (icons::house()) }
                span class="dock-label" { "Overview" }
            }
            a href="/workouts" {
                div class="size-[1.5em]" { (icons::barbell()) }
                span class="dock-label" { "Workouts" }
            }
            a href="/exercises" {
                div class="size-[1.5em]" { (icons::person_simple_run()) }
                span class="dock-label" { "Exercises" }
            }
        }
    }
}

fn header(title: &str, back_button: bool) -> Markup {
    html! {
        div class="flex items-center mb-5" {
            @if back_button {
                button onclick="history.back()" class="w-[1.6em] mr-1" {
                    (icons::arrow_left())
                }
            }
            h1 class="text-2xl" { (title) }
        }
    }
}
